# User Guide

This section contains basic guidance on installing and using the `coincident`
library

```{toctree}
:maxdepth: 1
:hidden:
:caption: Getting Started

installation
introduction
```

```{toctree}
:maxdepth: 1
:hidden:
:caption: Datasets

datasets
```

```{toctree}
:maxdepth: 1
:hidden:
:caption: Contributing

contribute
```
